@@ -10,11 +10,6 @@
 //
 //
 
-// enable > 2gb support (LFS)
-
-#define _LARGEFILE_SOURCE
-#define _LARGEFILE64_SOURCE 
-
 #include <tdelocale.h>
 #include <tdeglobal.h>
 #include <tdemessagebox.h>
